@@ -29,23 +29,22 @@
 #include <QtDeclarative/QDeclarativeContext>
 #include <QtDeclarative/QDeclarativeComponent>
 #include <QtDeclarative/QDeclarativeError>
-#include <QtGui/QHBoxLayout>
-#include <QtGui/QGraphicsDropShadowEffect>
-#include <QtGui/QGraphicsBlurEffect>
-#include <QtGui/QGraphicsObject>
-#include <QtGui/QLabel>
-#include <QtGui/QProgressBar>
-#include <QtGui/QPushButton>
-#include <QtGui/QVBoxLayout>
+#include <QHBoxLayout>
+#include <QGraphicsDropShadowEffect>
+#include <QGraphicsBlurEffect>
+#include <QGraphicsObject>
+#include <QtWidgets/QLabel>
+#include <QtWidgets/QProgressBar>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QVBoxLayout>
 
 // KDE includes
 #include <KDialog>
 #include <KGlobal>
 #include <KHBox>
-#include <KIcon>
 #include <KIO/Job>
 #include <KJob>
-#include <KLocale>
+#include <KLocalizedString>
 #include <KPixmapSequence>
 #include <kpixmapsequenceoverlaypainter.h>
 #include <KService>
@@ -316,7 +315,7 @@ void ResourceDetailsWidget::setResource(AbstractResource *resource)
 
     // FIXME: Always keep label size at 48x48, and render the largest size
     // we can up to that point. Otherwise some icons will be blurry
-    m_iconLabel->setPixmap(KIcon(resource->icon()).pixmap(48,48));
+    m_iconLabel->setPixmap(QIcon::fromTheme(resource->icon()).pixmap(48,48));
 
     m_nameLabel->setText(QLatin1Literal("<h1>") % resource->name() % QLatin1Literal("</h1>"));
     m_shortDescLabel->setText(resource->comment());
@@ -536,11 +535,11 @@ void ResourceDetailsWidget::updateActionButton()
     m_statusLabel->setText(m_resource->status());
     if (!m_resource->isInstalled()) {
         m_actionButton->setText(i18nc("@action", "Install"));
-        m_actionButton->setIcon(KIcon("download"));
+        m_actionButton->setIcon(QIcon::fromTheme("download"));
         m_actionButton->show();
     } else {
         m_actionButton->setText(i18nc("@action", "Remove"));
-        m_actionButton->setIcon(KIcon("edit-delete"));
+        m_actionButton->setIcon(QIcon::fromTheme("edit-delete"));
     }
 
     m_addonsWidget->setResource(m_resource);
