@@ -38,6 +38,7 @@
 #include <KProtocolManager>
 #include <KIO/Job>
 #include <KActionCollection>
+#include <KIconLoader>
 
 // QApt/DebconfKDE includes
 #include <QApt/Backend>
@@ -69,14 +70,12 @@ ApplicationBackend::ApplicationBackend(QObject* parent)
     , m_backend(new QApt::Backend(this))
     , m_reviewsBackend(new ReviewsBackend(this))
     , m_isFetching(true)
-    , m_wantedTransaction(nullptr)
     , m_currentTransaction(nullptr)
     , m_backendUpdater(new ApplicationUpdates(this))
     , m_aptify(nullptr)
     , m_aptBackendInitialized(false)
 {
-//   TODO: Port
-//     KGlobal::dirs()->addResourceDir("appicon", "/usr/share/app-install/icons/");
+    KIconLoader::global()->reconfigure(QString(), QStringList(QStringLiteral("/usr/share/app-install/icons/")));
 
     m_watcher = new QFutureWatcher<QVector<Application*> >(this);
     connect(m_watcher, SIGNAL(finished()), this, SLOT(setApplications()));
@@ -470,18 +469,12 @@ void ApplicationBackend::installApplication(AbstractResource* res, AddonList add
 {
     Application* app = qobject_cast<Application*>(res);
     Transaction::Role role = app->package()->isInstalled() ? Transaction::ChangeAddonsRole : Transaction::InstallRole;
-    QStringList pkgName;
-    pkgName << app->packageName();
-    m_wantedTransaction = new Transaction(this, res, role, addons);
-    aptListBugs(pkgName);
+    addTransaction(new Transaction(this, res, role, addons));
 }
 
 void ApplicationBackend::installApplication(AbstractResource* app)
 {
-    QStringList pkgName;
-    pkgName << app->packageName();
-    m_wantedTransaction = new Transaction(this, app, Transaction::InstallRole);
-    aptListBugs(pkgName);
+    addTransaction(new Transaction(this, app, Transaction::InstallRole));
 }
 
 void ApplicationBackend::removeApplication(AbstractResource* app)
@@ -671,44 +664,4 @@ void ApplicationBackend::setFetching(bool f)
     }
 }
 
-void ApplicationBackend::listBugsFinished()
-{
-    bool ok = true;
-    KProcess *mProcess = qobject_cast<KProcess*>(QObject::sender());
-    if (!mProcess) {
-        return;
-    }
-    QString output = QString::fromUtf8(mProcess->readAllStandardOutput());
-    mProcess->deleteLater();
-    if (!output.isEmpty()) {
-        QMessageBox::StandardButton reply;
-        reply = QMessageBox::question(mainWindow(), i18n("Bugs found"), output ,QMessageBox::Yes|QMessageBox::No);
-        if (reply == QMessageBox::No) {
-            ok = false;
-        }
-    }
-    if (ok) {
-        if (m_wantedTransaction){
-            addTransaction(m_wantedTransaction);
-            m_wantedTransaction = nullptr;
-        }
-        emit transactionOk();
-    }
-}
-
-void ApplicationBackend::aptListBugs(QStringList packageName)
-{
-    QStringList arguments;
-    QString program = QStandardPaths::findExecutable(QStringLiteral("apt-listbugs"));
-    if (program.isEmpty()) {
-        emit transactionOk();
-        return;
-    }
-    KProcess *proc = new KProcess;
-    proc->setOutputChannelMode(KProcess::OnlyStdoutChannel);
-    proc->setShellCommand(program.append(QStringLiteral(" list ")).append(packageName.join(" , ")));
-    connect(proc, SIGNAL(finished(int)), this, SLOT(listBugsFinished()));
-    proc->start();
-}
-
 #include "ApplicationBackend.moc"
