@@ -205,7 +205,7 @@ bool UpdateModel::setData(const QModelIndex &idx, const QVariant &value, int rol
         }
 
         checkResources(apps, newValue);
-        dataChanged(idx, idx);
+        emit dataChanged(idx, idx);
         if (type == UpdateItem::ItemType::ApplicationItem) {
             QModelIndex parentIndex = idx.parent();
             emit dataChanged(parentIndex, parentIndex);
@@ -219,12 +219,6 @@ bool UpdateModel::setData(const QModelIndex &idx, const QVariant &value, int rol
     return false;
 }
 
-void UpdateModel::packageChanged()
-{
-    // We don't know what changed or not, so say everything changed
-    emit dataChanged(index(0, 0), QModelIndex());
-}
-
 void UpdateModel::setResources(const QList< AbstractResource* >& resources)
 {
     beginResetModel();
